@@ -2,7 +2,7 @@
 #'
 #' @description This function extracts the backbone of a network
 #' @param G igraph network
-#' @param alpha Signifcance level
+#' @param alpha Significance level
 #' @param directed Default is TRUE
 #' @export
 #' @return Backbone of the network
@@ -23,7 +23,7 @@
 get.backbone<-function(G, alpha, directed = TRUE){
   # get edgelist
   edgelist<-igraph::get.data.frame(G)
-  colnames(edgelist) = c("from","to","weight")
+  colnames(edgelist) <- c("from","to","weight")
 
   # get nodes list
   nodes<- unique(c(edgelist[,1], edgelist[,2]))
@@ -39,37 +39,37 @@ get.backbone<-function(G, alpha, directed = TRUE){
   for (i in 1:N) # for each node
   {
     # get neighbors
-    nei = edgelist[edgelist$from == nodes[i],]
-    nei = rbind(nei, edgelist[edgelist$to == nodes[i],])
+    nei <- edgelist[edgelist$from == nodes[i],]
+    nei <- rbind(nei, edgelist[edgelist$to == nodes[i],])
 
     # get degree for node i
-    k_i = length(edgelist$to[edgelist$to == nodes[i]]) + length(edgelist$to[edgelist$from == nodes[i]])
+    k_i <- length(edgelist$to[edgelist$to == nodes[i]]) + length(edgelist$to[edgelist$from == nodes[i]])
 
     if (k_i>1)
     {
       for (j in 1:k_i) # for each neighbor
       {
         # compute weighted edge
-        p_ij = as.numeric(nei$weight[j]) / sum(as.numeric(nei$weight))
+        p_ij <- as.numeric(nei$weight[j]) / sum(as.numeric(nei$weight))
 
         # VIA INTEGRATION
         #integrand_i = function(x){(1-x)^(k_i-2)}
         #integration = integrate(integrand_i, lower = 0, upper = p_ij)
         #alpha_ij = 1 - (k_i - 1) * integration$value
 
-        alpha_ij = (1 - p_ij)^(k_i - 1)
+        alpha_ij <- (1 - p_ij)^(k_i - 1)
 
         if (alpha_ij < alpha)
         {
-          backbone = rbind(backbone, c(nei$from[j], nei$to[j], nei$weight[j]))
+          backbone <- rbind(backbone, c(nei$from[j], nei$to[j], nei$weight[j]))
         }
       }
     }
   }
 
-  colnames(backbone) = c("from","to","weight")
-  backbone = unique(backbone[,c('from','to','weight')])
-  G_backbone = igraph::graph.data.frame(backbone, directed = directed)
+  colnames(backbone) <- c("from","to","weight")
+  backbone <- unique(backbone[,c('from','to','weight')])
+  G_backbone <- igraph::graph.data.frame(backbone, directed = directed)
 
   return(G_backbone)
 }
